@@ -393,8 +393,8 @@ void Circuit::loadStrDoc( QString &doc )
                     }
                     comp->setPropStr( "label", label ); //setIdLabel( label );
 
-                    QList<propGroup> groups = comp->properties(); // Set properties in correct order
-                    for( propGroup group : groups )
+                    QList<propGroup>* groups = comp->properties(); // Set properties in correct order
+                    for( propGroup group : *groups )
                     {
                         QList<ComProperty*> propList = group.propList;
                         if( propList.isEmpty() ) continue;
@@ -443,6 +443,8 @@ void Circuit::loadStrDoc( QString &doc )
         for( Component* comp : nodeList ) { comp->setSelected( true ); comp->move( m_deltaMove ); }
         for( Connector* con  : conList )  { con->setSelected( true );  con->move( m_deltaMove ); }
     }
+    else for( Component* comp : compList ) { comp->moveSignal(); }
+
     for( Linkable* l : linkList )
         l->createLinks( &compList );
 
