@@ -39,9 +39,9 @@ QList<ComProperty*> IoComponent::inputProps()
 {
     return {
 new ComProperty( "", tr("Inputs:"),"","",0),
-new DoubProp<IoComponent>( "Input_High_V", tr("Low to High Threshold"),"V", this, &IoComponent::inputHighV, &IoComponent::setInputHighV ),
-new DoubProp<IoComponent>( "Input_Low_V" , tr("High to Low Threshold"),"V", this, &IoComponent::inputLowV,  &IoComponent::setInputLowV ),
-new DoubProp<IoComponent>( "Input_Imped" , tr("Input Impedance")      ,"Ω", this, &IoComponent::inputImp,   &IoComponent::setInputImp ) };
+new DoubProp<IoComponent>( "Input_High_V", tr("Low to High Threshold"),"V" , this, &IoComponent::inputHighV, &IoComponent::setInputHighV ),
+new DoubProp<IoComponent>( "Input_Low_V" , tr("High to Low Threshold"),"V" , this, &IoComponent::inputLowV,  &IoComponent::setInputLowV ),
+new DoubProp<IoComponent>( "Input_Imped" , tr("Input Impedance")      ,"MΩ", this, &IoComponent::inputImp,   &IoComponent::setInputImp ) };
 }
 
 QList<ComProperty*> IoComponent::outputProps()
@@ -227,14 +227,25 @@ void IoComponent::setOpenCol( bool op )
     Simulator::self()->resumeSim();
 }
 
+void IoComponent::setPropDelay( double pd )
+{
+    if( pd < 1e-12 ) pd = 1e-12;
+    if( pd > 1e6   ) pd = 1e6;
+    m_propDelay = pd*1e12;
+}
+
 void IoComponent::setRiseTime( double time )
 {
+    if( time < 1e-12 ) time = 1e-12;
+    if( time > 1e6   ) time = 1e6;
     m_timeLH = time*1e12;
     for( IoPin* pin : m_outPin ) pin->setRiseTime( m_timeLH*1.25 );
 }
 
 void IoComponent::setFallTime( double time )
 {
+    if( time < 1e-12 ) time = 1e-12;
+    if( time > 1e6   ) time = 1e6;
     m_timeHL = time*1e12;
     for( IoPin* pin : m_outPin ) pin->setFallTime( m_timeHL*1.25 );
 }
