@@ -16,12 +16,18 @@ class MAINMODULE_EXPORT SevenSegmentBCD : public BcdBase
         SevenSegmentBCD( QObject* parent, QString type, QString id );
         ~SevenSegmentBCD();
 
-        static Component* construct( QObject* parent, QString type, QString id );
-        static LibraryItem* libraryItem();
+ static Component* construct( QObject* parent, QString type, QString id );
+ static LibraryItem* libraryItem();
 
-        void updateStep() override;
+        virtual void updateStep() override;
+
+        virtual void setLinked( bool l ) override;
+        virtual void setLinkedValue( int v, int i=0  ) override;
         
-        void paint( QPainter* p, const QStyleOptionGraphicsItem* option, QWidget* widget );
+        void paint( QPainter* p, const QStyleOptionGraphicsItem* option, QWidget* widget ) override;
+
+    private:
+        int m_intensity;
 };
 
 #endif
