@@ -39,12 +39,12 @@ Lamp::Lamp( QObject* parent, QString type, QString id )
     m_ePin[1] = m_pin[1];
 
     Simulator::self()->addToUpdateList( this );
-    initialize();
+    Lamp::initialize();
 
     addPropGroup( { tr("Main"), {
 new DoubProp<Lamp>( "Resistance", tr("Resistance"), "Ω", this, &Lamp::getRes, &Lamp::setResSafe ),
 new DoubProp<Lamp>( "MaxCurrent", tr("Max Current"),"A", this, &Lamp::maxCurrent, &Lamp::setMaxCurrent ),
-    } } );
+    },0 } );
 }
 Lamp::~Lamp(){}
 
