@@ -40,23 +40,22 @@ LedMatrix::LedMatrix( QObject* parent, QString type, QString id )
     m_resist  = 0.6;
     m_maxCurr = 0.02;
     m_threshold = 2.4;
-    
-    m_ledColor = 0;
+
     m_color = QColor(0,0,0);
     m_verticalPins = false;
     createMatrix();
 
     addPropGroup( { tr("Main"), {
-new IntProp   <LedMatrix>( "Rows"         , tr("Rows")     ,"_Leds", this, &LedMatrix::rows,     &LedMatrix::setRows, "uint" ),
-new IntProp   <LedMatrix>( "Cols"         , tr("Columns")  ,"_Leds", this, &LedMatrix::cols,     &LedMatrix::setCols, "uint" ),
-new StringProp<LedMatrix>( "Color"        , tr("Color")        ,"" , this, &LedMatrix::colorStr, &LedMatrix::setColorStr, "enum" ),
-new BoolProp  <LedMatrix>( "Vertical_Pins", tr("Vertical Pins"),"" , this, &LedMatrix::verticalPins, &LedMatrix::setVerticalPins ),
-    }} );
+new IntProp <LedMatrix>("Rows"         , tr("Rows")     ,"_Leds", this, &LedMatrix::rows,     &LedMatrix::setRows,0,"uint" ),
+new IntProp <LedMatrix>("Cols"         , tr("Columns")  ,"_Leds", this, &LedMatrix::cols,     &LedMatrix::setCols,0,"uint" ),
+new StrProp <LedMatrix>("Color"        , tr("Color")        ,"" , this, &LedMatrix::colorStr, &LedMatrix::setColorStr,0,"enum" ),
+new BoolProp<LedMatrix>("Vertical_Pins", tr("Vertical Pins"),"" , this, &LedMatrix::verticalPins, &LedMatrix::setVerticalPins ),
+    }, groupNoCopy} );
     addPropGroup( { tr("Electric"), {
-new DoubProp<LedMatrix>( "Threshold" , tr("Forward Voltage"),"V", this, &LedMatrix::threshold,  &LedMatrix::setThreshold ),
-new DoubProp<LedMatrix>( "MaxCurrent", tr("Max Current")    ,"A", this, &LedMatrix::maxCurrent, &LedMatrix::setMaxCurrent ),
-new DoubProp<LedMatrix>( "Resistance", tr("Resistance")     ,"Ω", this, &LedMatrix::res,        &LedMatrix::setRes ),
-    }} );
+new DoubProp<LedMatrix>("Threshold" , tr("Forward Voltage"),"V", this, &LedMatrix::threshold,  &LedMatrix::setThreshold ),
+new DoubProp<LedMatrix>("MaxCurrent", tr("Max Current")    ,"A", this, &LedMatrix::maxCurrent, &LedMatrix::setMaxCurrent ),
+new DoubProp<LedMatrix>("Resistance", tr("Resistance")     ,"Ω", this, &LedMatrix::res,        &LedMatrix::setRes ),
+    }, groupNoCopy} );
 }
 LedMatrix::~LedMatrix(){}
 
