@@ -74,7 +74,7 @@ void Thermistor::paint( QPainter* p, const QStyleOptionGraphicsItem* option, QWi
 
     Component::paint( p, option, widget );
 
-    p->drawRect( QRectF(-10.5, -4, 21, 8 ));
+    p->drawRect( QRectF(-11,-4.5, 22, 9 ));
     
     p->drawLine(-8, 6,  6,-8 );
     p->drawLine( 6,-8, 10,-8 );
