@@ -6,22 +6,23 @@
 #ifndef POTENTIOMETER_H
 #define POTENTIOMETER_H
 
-#include "component.h"
+#include "dialed.h"
 #include "e-resistor.h"
-#include "e-element.h"
-#include "dialwidget.h"
 #include "pin.h"
 
 class LibraryItem;
 
-class MAINMODULE_EXPORT Potentiometer : public Component, public eElement
+class MAINMODULE_EXPORT Potentiometer : public Dialed, public eElement
 {
     public:
         Potentiometer( QObject* parent, QString type, QString id );
         ~Potentiometer();
 
-        static Component* construct( QObject* parent, QString type, QString id );
-        static LibraryItem* libraryItem();
+ static Component* construct( QObject* parent, QString type, QString id );
+ static LibraryItem* libraryItem();
+
+        virtual void stamp() override;
+        virtual void updateStep() override;
 
         double getVal();
         void setVal( double val );
@@ -29,21 +30,18 @@ class MAINMODULE_EXPORT Potentiometer : public Component, public eElement
         double getRes() { return m_resist; }
         void setRes( double v );
 
-        virtual void stamp() override;
-        virtual void updateStep() override;
+        virtual void setLinkedValue( int v, int i=0 ) override;
 
-        virtual void paint( QPainter* p, const QStyleOptionGraphicsItem* option, QWidget* widget );
+        virtual void paint( QPainter* p, const QStyleOptionGraphicsItem* option, QWidget* widget ) override;
 
-    public slots:
-        void resChanged( int volt );
+    protected:
+        virtual void updateProxy() override;
 
     private:
         double m_resist;
         double m_voltOut;
         double m_res1;
 
-        bool m_changed;
-        
         Pin m_pinA;
         Pin m_pinM;
         Pin m_pinB;
@@ -54,10 +52,6 @@ class MAINMODULE_EXPORT Potentiometer : public Component, public eElement
         eResistor m_resB;
         
         eNode* m_midEnode;
-        
-        QDial* m_dial;
-        DialWidget m_dialW;
-        QGraphicsProxyWidget* m_proxy;
 };
 
 #endif
