@@ -29,13 +29,14 @@ eMcu::eMcu( Mcu* comp, QString id )
 {
     m_component = comp;
 
-    cpu = NULL;
-    m_wdt = NULL;
-    m_intOsc = NULL;
-    m_clkPin = NULL;
+    cpu          = NULL;
+    m_wdt        = NULL;
+    m_intOsc     = NULL;
+    m_comparator = NULL;
+    m_clkPin     = NULL;
+    m_cfgWord    = NULL;
     m_vrefModule = NULL;
     m_sleepModule = NULL;
-    m_cfgWord = NULL;
 
     m_freq = 0;
     m_cPerInst = 1;
@@ -145,8 +146,9 @@ void eMcu::reset()
     m_cycle = 0;
     cyclesDone = 0;
 
-    for( McuModule* module : m_modules ) module->reset();
-    for( IoPort* ioPort : m_ioPorts ) ioPort->reset();
+    for( McuModule* module : m_modules  ) module->reset();
+    for( IoPort*    ioPort : m_ioPorts  ) ioPort->reset();
+    for( McuPort*  mcuPort : m_mcuPorts ) mcuPort->reset();
 
     m_interrupts.resetInts();
     DataSpace::initialize();
@@ -154,6 +156,8 @@ void eMcu::reset()
     if( cpu ) cpu->reset(); // Must be after all modules reset
     else qDebug() << "ERROR: eMcu::reset NULL Cpu";
 
+    for( McuPort*  mcuPort : m_mcuPorts ) mcuPort->readPort( 0 ); // Update Pin Input register
+
     if( !m_saveEepr )
         for( uint i=0; i<m_romSize; ++i ) setRomValue( i, 0xFF );
 }
