@@ -204,11 +204,20 @@ new BoolProp<Mcu>("Logic_Symbol", tr("Logic Symbol") ,"", this, &Mcu::logicSymbo
     }, 0} );
 
     addPropGroup( { tr("Config"), {
-new BoolProp<Mcu>("Rst_enabled", tr("Enable Reset Pin")   ,"", this, &Mcu::rstPinEnabled, &Mcu::enableRstPin ),
-new BoolProp<Mcu>("Ext_Osc"    , tr("External Oscillator"),"", this, &Mcu::extOscEnabled, &Mcu::enableExtOsc ),
-new BoolProp<Mcu>("Wdt_enabled", tr("Enable WatchDog")    ,"", this, &Mcu::wdtEnabled   , &Mcu::enableWdt ),
-new BoolProp<Mcu>("Clk_Out"    , tr("Clock Out")          ,"", this, &Mcu::clockOut     , &Mcu::setClockOut )
-    }, groupNoCopy} );
+new ComProperty( "", tr("Changes applied after Simulation Restart"),"","",0),
+                    }, groupNoCopy} );
+
+if( m_portRstPin )
+addProperty(tr("Config"),new BoolProp<Mcu>("Rst_enabled", tr("Enable Reset Pin")   ,"", this, &Mcu::rstPinEnabled, &Mcu::enableRstPin ) );
+
+if( m_eMcu.m_intOsc && m_eMcu.m_intOsc->clkInPin() )
+addProperty(tr("Config"),new BoolProp<Mcu>("Ext_Osc"    , tr("External Oscillator"),"", this, &Mcu::extOscEnabled, &Mcu::enableExtOsc ) );
+
+if( m_eMcu.m_wdt )
+addProperty(tr("Config"),new BoolProp<Mcu>("Wdt_enabled", tr("Enable WatchDog")    ,"", this, &Mcu::wdtEnabled   , &Mcu::enableWdt ) );
+
+if( m_eMcu.m_intOsc && m_eMcu.m_intOsc->clkOutPin() )
+addProperty(tr("Config"),new BoolProp<Mcu>("Clk_Out"    , tr("Clock Out")          ,"", this, &Mcu::clockOut     , &Mcu::setClockOut ) );
 
     addPropGroup( {"Hidden", {
 new StrProp<Mcu>("varList"  ,"","", this, &Mcu::varList,   &Mcu::setVarList),
@@ -532,18 +541,6 @@ int Mcu::serialMon()
 
 void Mcu::setSerialMon( int s ) { if( s>=0 ) slotOpenTerm( s ); }
 
-void Mcu::setLinkedVal( int index, int v, int i )
-{
-    if( index >= m_linkedComp.size() ) return;
-    m_linkedComp.at( index )->setLinkedValue( v, i );
-}
-
-void Mcu::setLinkedStr( int index, QString str, int i )
-{
-    if( index >= m_linkedComp.size() ) return;
-    m_linkedComp.at( index )->setLinkedString( str, i );
-}
-
 void Mcu::setLinkedValue( int v, int i )
 {
     if( m_scriptLink ) m_scriptLink->setLinkedVal( v, i );
